@@ -5,8 +5,9 @@ use strict;
 BEGIN {
     use Exporter ();
 
-    use vars qw(@ISA @EXPORT_OK);
+    use vars qw($VERSION @ISA @EXPORT_OK);
 
+    $VERSION = '0.01';
     @ISA = qw(Exporter);
 
     @EXPORT_OK = qw(
@@ -39,7 +40,7 @@ our %Verify = (
         )),
     },
 
-    'ALIGN' => {
+    'JUSTIFY' => {
         '__DEFAULT__' => 'left',
 #GGG Add a full-justify option - this requires a lot of coding prowess
         ( map { $_ => 1 } qw(
@@ -65,31 +66,31 @@ our %Verify = (
     'PAGESIZE' => {
         '__DEFAULT__' => 'Letter',
         'Letter' => {
-            PAGE_WIDTH  => 8.5 * $PointsPer{I},
+            PAGE_WIDTH => 8.5 * $PointsPer{I},
             PAGE_HEIGHT => 11 * $PointsPer{I},
         },
         'Legal' => {
-            PAGE_WIDTH  => 8.5 * $PointsPer{I},
+            PAGE_WIDTH => 8.5 * $PointsPer{I},
             PAGE_HEIGHT => 14 * $PointsPer{I},
         },
         'A0' => {
-            PAGE_WIDTH  => 2380,
+            PAGE_WIDTH => 2380,
             PAGE_HEIGHT => 3368,
         },
         'A1' => {
-            PAGE_WIDTH  => 1684,
+            PAGE_WIDTH => 1684,
             PAGE_HEIGHT => 2380,
         },
         'A2' => {
-            PAGE_WIDTH  => 1190,
+            PAGE_WIDTH => 1190,
             PAGE_HEIGHT => 1684,
         },
         'A3' => {
-            PAGE_WIDTH  => 842,
-            PAGE_HEIGHT => 1190,
+            PAGE_WIDTH => 1190,
+            PAGE_HEIGHT => 842,
         },
         'A4' => {
-            PAGE_WIDTH  => 595,
+            PAGE_WIDTH => 595,
             PAGE_HEIGHT => 842,
         },
     },
@@ -97,3 +98,31 @@ our %Verify = (
 
 1;
 __END__
+
+=head1 NAME
+
+PDF::Template::Constants
+
+=head1 PURPOSE
+
+=head1 NODE NAME
+
+=head1 INHERITANCE
+
+=head1 ATTRIBUTES
+
+=head1 CHILDREN
+
+=head1 AFFECTS
+
+=head1 DEPENDENCIES
+
+=head1 USAGE
+
+=head1 AUTHOR
+
+Rob Kinyon (rkinyon@columbus.rr.com)
+
+=head1 SEE ALSO
+
+=cut
