@@ -34,7 +34,6 @@ sub conditional_passes
     $val = @{$val} while UNIVERSAL::isa($val, 'ARRAY');
     $val = ${$val} while UNIVERSAL::isa($val, 'SCALAR');
 
-    my $istrue = (defined $val && $val) ? 1 : 0;
     my $value = $context->get($self, 'VALUE');
     if (defined $value)
     {
@@ -43,6 +42,10 @@ sub conditional_passes
             ? $isOp{$op}
             : '==';
 
+        # Force numerical context on both values;
+        $value *= 1;
+        $val *= 1;
+
         my $res;
         for ($op)
         {
@@ -59,27 +62,28 @@ sub conditional_passes
             /^ge$/ && do { $res = ($val ge $value); last };
             /^le$/ && do { $res = ($val le $value); last };
 
-            die "Unknown operator '$op' in conditional resolve", $/;
+            die "Unknown operator in conditional resolve", $/;
         }
 
-        return 1;
+        return 0 unless $res;
     }
     elsif (my $is = uc $context->get($self, 'IS'))
     {
+        my $istrue = $val && 1;
         if ($is eq 'TRUE')
         {
-            return $istrue;
+            return 0 unless $istrue;
         }
         else
         {
             warn "Conditional 'is' value was [$is], defaulting to 'FALSE'" . $/
                 if $is ne 'FALSE';
 
-            return !$istrue;
+            return 0 if $istrue;
         }
     }
 
-    return $istrue;
+    return 1;
 }
 
 sub render
@@ -114,23 +118,6 @@ sub total_of
     return $self->SUPER::total_of($context, $attr);
 }
 
-sub _do_page
-{
-    my $self = shift;
-    return unless $self->conditional_passes(@_);
-    return $self->SUPER::_do_page( @_ );
-}
-
-sub begin_page
-{
-    _do_page(@_,'begin_page');
-}
-
-sub end_page
-{
-    _do_page(@_,'end_page');
-}
-
 1;
 __END__
 
@@ -168,13 +155,9 @@ attribute, so if you want a parameter, prepend it with '$'.
 
 =item * IS - If there is no VALUE attribute, this will be checked. IS can be
 either 'FALSE' or 'TRUE'. The boolean of NAME will be compared and the
-conditional will branch appropriately. If NAME has no value, this will fail.
+conditional will branch appropriately.
 
-=item * NONE - If there is no IS and no VALUE, then an attempt will be made to
-find the variable defined by NAME. If it exists and is true, the condition
-will succeed. Otherwise, it will fail.
-
-=back
+=back 4
 
 =head1 CHILDREN
 
@@ -190,13 +173,17 @@ None
 
 =head1 USAGE
 
-  <if name="__PAGE__" OP="!=" VALUE="__LAST_PAGE__">
-    ... Children execute if the current page is not the last page ...
-  </if>
+<if name="__PAGE__" OP="!=" VALUE="__LAST_PAGE__">
 
-  <if name="Param1" OP="eq" VALUE="$Param2">
-    ... Children execute if Param1 is string-wise equals to Param2 ...
-  </if>
+  ... Children execute if the current page is not the last page ...
+
+</if>
+
+<if name="Param1" OP="eq" VALUE="$Param2">
+
+  ... Children execute if Param1 is string-wise equals to Param2 ...
+
+</if>
 
 =head1 AUTHOR
 
