@@ -25,7 +25,6 @@ sub render
 {
     my $self = shift;
     my ($context) = @_;
-    my $p = $context->{PDF};
 
     my $size = $context->get($self, 'H') ||
         $context->get($self, 'SIZE') ||
@@ -36,7 +35,11 @@ sub render
     my $font = $context->retrieve_font($face);
     $font == -1 && die "Font not found for '$face' by the time <font> was rendered", $/;
 
-    $p->font($font, $size);
+    pdflib_pl::PDF_setfont(
+        $context->{PDF},
+        $font,
+        $size,
+    );
 
     push @current_font, [ $font, $size ];
 
@@ -48,7 +51,7 @@ sub render
 
     return $child_success unless @current_font;
 
-    $p->font(@{$current_font[-1]});
+    pdflib_pl::PDF_setfont($context->{PDF}, @{$current_font[-1]});
 
     return $child_success;
 }
@@ -66,17 +69,21 @@ sub begin_page
     unless ($context->retrieve_font($face))
     {
         my $encoding = $context->get($self, 'PDF_ENCODING') || 'host';
+#        $self->_validate_option('FACE', \$face)
+#            unless $encoding eq 'host';
 
-        my $font = $context->{PDF}->find_font(
+        my $font = pdflib_pl::PDF_findfont(
+            $context->{PDF},
             $face,
             $encoding,
             $context->get($self, 'EMBED'),
-        ) or die "Font not found for '$face' by the time <font> was rendered", $/;
+        );
+        $font == -1 && die "Font not found for '$face' by the time <font> was rendered", $/;
 
         $context->store_font($face, $font);
     }
 
-    return $self->SUPER::begin_page($context);
+    return 1;
 }
 
 1;
@@ -107,7 +114,7 @@ PDFLib. (q.v. for more details)
 
 =item * H - the point size of the font. 
 
-=back
+=back 4
 
 =head1 CHILDREN
 
@@ -123,34 +130,31 @@ None
 
 =head1 USAGE
 
-  <font face="Times-Roman" h="8">
+<font face="Times-Roman" h="8">
 
-    ... Children will be rendered in 8-point TimesRoman font ...
+  ... Children will be rendered in 8-point TimesRoman font ...
 
-  </font>
+</font>
 
 Please note that not specifying a FONT tag will result in a PDFLib error when
 the first TEXTBOX attempts to render. Since not all PDF documents involve text,
 PDF::Template does not require a FONT tag.
 
-(I might require a FONT tag if a TEXTBOX tag exists, but only after the non-
-standard behavior of FONT is fixed. q.v. the NOTE below.)
-
 =head1 NOTE
 
 For backwards compatability, a stand-alone FONT tag will be treated as if it is
 the parent for all nodes until the end of the parent node. This behavior is
 deprecated and will be removed in a future release.
 
-  <pagedef>
+<pagedef>
 
-    ... Children here aren't affected by the FONT tag below ...
+  ... Children here aren't affected by the FONT tag below ...
 
-    <font face="Times-Roman" h="8"/>
+  <font face="Times-Roman" h="8"/>
 
-    ... Children here _ARE_ affected by the FONT tag above ...
+  ... Children here _ARE_ affected by the FONT tag above ...
 
-  </pagedef>
+</pagedef>
 
 =head1 AUTHOR
 
