@@ -14,14 +14,13 @@ sub enter_scope
     my $self = shift;
     my ($context) = @_;
 
-    $self->SUPER::enter_scope($context);
-
     @{$self}{qw/OLD_X OLD_Y/} = map { $context->get($self, $_) } qw(X Y);
 
     $context->{X} = 0;
-    $context->{Y} = $context->get($self, 'FOOTER_HEIGHT');
+#GGG
+    $context->{Y} = $context->resolve($self, 'FOOTER_HEIGHT');
 
-    return 1;
+    return $self->SUPER::enter_scope($context);
 }
 
 1;
@@ -50,7 +49,7 @@ PDF::Template::Container::Margin
 =item * FOOTER_HEIGHT - the amount reserved for the footer from the bottom of
 the page.
 
-=back
+=back 4
 
 =head1 CHILDREN
 
@@ -66,12 +65,17 @@ None
 
 =head1 USAGE
 
-  <pagedef>
-    ... Stuff here ...
-    <footer footer_height="1i">
-      ... Children here will render on every page ...
-    </footer>
-  </pagedef>
+<pagedef>
+
+  ... Stuff here ...
+
+  <footer footer_height="1i">
+
+    ... Children here will render on every page ...
+
+  </footer>
+
+</pagedef>
 
 =head1 AUTHOR
 
