@@ -14,14 +14,12 @@ sub enter_scope
     my $self = shift;
     my ($context) = @_;
 
-    $self->SUPER::enter_scope( $context );
-
     @{$self}{qw/OLD_X OLD_Y/} = map { $context->get($self, $_) } qw(X Y);
 
     $context->{X} = 0;
-    $context->{Y} = $context->get($self, 'PAGE_HEIGHT');
+    $context->{Y} = $context->resolve($self, 'PAGE_HEIGHT');
 
-    return 1;
+    return $self->SUPER::enter_scope($context);
 }
 
 1;
@@ -50,7 +48,7 @@ PDF::Template::Container::Margin
 =item * HEADER_HEIGHT - the amount reserved for the header from the bottom of
 the page.
 
-=back
+=back 4
 
 =head1 CHILDREN
 
@@ -66,12 +64,17 @@ None
 
 =head1 USAGE
 
-  <pagedef>
-    <header header_height="1i">
-      ... Children here will render on every page ...
-    </header>
-    ... Stuff here ...
-  </pagedef>
+<pagedef>
+
+  <header header_height="1i">
+
+    ... Children here will render on every page ...
+
+  </header>
+
+  ... Stuff here ...
+
+</pagedef>
 
 =head1 AUTHOR
 
