@@ -26,34 +26,6 @@ sub new
     return $self;
 }
 
-sub _do_page
-{
-    my $self=shift;
-    my ($context) = @_;
-    return 0 unless $self->should_render($context);
-    unless ($self->{ITERATOR} && $self->{ITERATOR}->more_params)
-    { $self->{ITERATOR} = $self->make_iterator($context); }
-    my $iterator = $self->{ITERATOR};
-    $iterator->enter_scope;
-    while ($iterator->can_continue)
-    {
-        $iterator->next;
-        $self->SUPER::begin_page($context);
-    }
-    $iterator->exit_scope;
-    return 1;
-}
-
-sub begin_page
-{
-    _do_page(@_,'begin_page');
-}
-
-sub end_page
-{
-    _do_page(@_,'end_page');
-}
-
 sub make_iterator
 {
     my $self = shift;
@@ -168,7 +140,7 @@ PDF::Template::Container
 
 =item * NAME - the name of a parameter that points to an array of hashes.
 
-=back
+=back 4
 
 =head1 CHILDREN
 
@@ -184,9 +156,11 @@ FOOTER - indicates where to pagebreak
 
 =head1 USAGE
 
-  <loop name="LOOPY">
-    ... Children here ...
-  </loop>
+<loop name="LOOPY">
+
+  ... Children here ...
+
+</loop>
 
 The children tags will have access to the values specified in LOOPY, as well as
 the parameters specifed outside.
