@@ -35,24 +35,24 @@ sub find_margin_heights
     $sub = sub {
         my $obj = shift;
 
-        $obj->enter_scope($context) unless $obj->isa('PAGEDEF');
+        $obj->enter_scope($context);
 
         if ($obj->isa('HEADER'))
         {
             die "Cannot have two <header> tags in the same <pagedef>", $/ if defined $header_height;
-            $header_height = $context->get($obj, 'HEADER_HEIGHT');
+            $header_height = int($context->get($obj, 'HEADER_HEIGHT') + 0.499);
         }
         elsif ($obj->isa('FOOTER'))
         {
             die "Cannot have two <footer> tags in the same <pagedef>", $/ if defined $footer_height;
-            $footer_height = $context->get($obj, 'FOOTER_HEIGHT');
+            $footer_height = int($context->get($obj, 'FOOTER_HEIGHT') + 0.499);
         }
         else
         {
             $sub->($_) for grep { $_->isa('CONTAINER') } @{$obj->{ELEMENTS}};
         }
 
-        $obj->exit_scope($context, 1) unless $obj->isa('PAGEDEF');
+        $obj->exit_scope($context, 1);
     };
 
     $sub->($self);
@@ -63,50 +63,6 @@ sub find_margin_heights
     return ($header_height, $footer_height);
 }
 
-sub enter_scope
-{
-    my $self = shift;
-    my ($context) = @_;
-
-    $self->SUPER::enter_scope( $context );
-
-    my ($pheight, $pwidth) = map { $context->get($self, $_) } qw(PAGE_HEIGHT PAGE_WIDTH);
-    unless (defined $pheight && defined $pwidth)
-    {
-        my $psize = $context->get($self, 'PAGESIZE');
-        $self->_validate_option('PAGESIZE', \$psize);
-
-        for my $attr (qw(PAGE_HEIGHT PAGE_WIDTH))
-        {
-            $self->{$attr} = $Verify{PAGESIZE}{$psize}{$attr};
-        }
-        ($pheight, $pwidth) = @{$self}{qw(PAGE_HEIGHT PAGE_WIDTH)};
-    }
-
-    # swap dimensions if landscape
-    if ($context->get($self, 'LANDSCAPE'))
-    {
-        ($pheight, $pwidth) = ($pwidth, $pheight);
-
-        @{$self}{qw(PAGE_HEIGHT PAGE_WIDTH)}
-            = @{$self}{qw(_ORIG_WIDTH _ORIG_HEIGHT)}
-            = @{$self}{qw(PAGE_WIDTH PAGE_HEIGHT)}
-    }
-
-    return 1;
-}
-
-sub exit_scope
-{
-    my $self = shift;
-    my ($context) = @_;
-
-    @{$self}{qw(PAGE_HEIGHT PAGE_WIDTH)} = delete @{$self}{qw(_ORIG_HEIGHT _ORIG_WIDTH)}
-        if exists $self->{_ORIG_HEIGHT};
-
-    return $self->SUPER::exit_scope($context);
-}
-
 sub begin_page
 {
     my $self = shift;
@@ -125,10 +81,30 @@ sub render
     my $self = shift;
     my ($context) = @_;
 
-    my ($header_h, $footer_h) = $self->find_margin_heights($context);
-
     my ($pheight, $pwidth) = map { $context->get($self, $_) } qw(PAGE_HEIGHT PAGE_WIDTH);
+    unless (defined $pheight && defined $pwidth)
+    {
+        my $psize = $context->get($self, 'PAGESIZE');
+        $self->_validate_option('PAGESIZE', \$psize);
 
+        for my $attr (qw(PAGE_HEIGHT PAGE_WIDTH))
+        {
+            $self->{$attr} = $Verify{PAGESIZE}{$psize}{$attr};
+        }
+        ($pheight, $pwidth) = @{$self}{qw(PAGE_HEIGHT PAGE_WIDTH)};
+    }
+
+    # swap dimensions if landscape
+    my ($orig_width, $orig_height);
+    if ($context->get($self, 'LANDSCAPE'))
+    {
+        ($pheight, $pwidth) = ($pwidth, $pheight);
+        ($self->{PAGE_HEIGHT}, $self->{PAGE_WIDTH})
+            = ($orig_width, $orig_height)
+            = ($self->{PAGE_WIDTH}, $self->{PAGE_HEIGHT});
+    }
+
+    my ($header_h, $footer_h) = $self->find_margin_heights($context);
     $self->{START_Y} = $pheight - $header_h;
     $self->{END_Y}   = $footer_h;
 
@@ -137,17 +113,24 @@ sub render
     my $done = 0;
     while (!$done)
     {
+        $self->enter_scope($context);
         $self->begin_page($context);
-        $context->{PDF}->begin_page($pwidth, $pheight);
+
+        pdflib_pl::PDF_begin_page($context->{PDF}, $pwidth, $pheight);
 
         $done = $self->iterate_over_children($context);
 
-        $context->{PDF}->end_page;
+        pdflib_pl::PDF_end_page($context->{PDF});
+
         $self->end_page($context);
+        $self->exit_scope($context);
 
         $context->increment_pagenumber unless $context->get($self, 'NOPAGENUMBER');
     }
 
+    ($self->{PAGE_WIDTH}, $self->{PAGE_HEIGHT}) = ($orig_width, $orig_height)
+        if defined $orig_width;
+
     return $done;
 }
 
@@ -193,7 +176,7 @@ a true value, then PAGE_HEIGHT and PAGE_WIDTH will be swapped.
 =item * NOPAGENUMBER - If this is set to a true value, then this pagedef will
 not increment the __PAGE__ parameter. Useful for title pages and the like.
 
-=back
+=back 4
 
 =head1 CHILDREN
 
@@ -209,27 +192,35 @@ None
 
 =head1 USAGE
 
-  <pagedef pagesize="Legal" landscape="1">
-    ... Children will render to a Legal-sized paper in landscape orientation ...
-  </pagedef>
+<pagedef pagesize="Legal" landscape="1">
+
+  ... Children will render to a Legal-sized paper in landscape orientation ...
+
+</pagedef>
 
 =head1 NOTE
 
 It is very possible, and often useful, to have more than one pagedef in a given
-template. Also, the PAGEDEF does not have to be the direct child of the
+template. Also, the PAGEDEF does not have to be the direct child of the 
 PDFTEMPLATE node. It is sometimes useful to have something like:
 
-  <pdftemplate>
-    <loop name="PAGEDEFS">
-      <pagedef
+<pdftemplate>
+
+  <loop name="PAGEDEFS">
+
+    <pagedef
         pagesize="$PaperSize"
         landscape="$Orientation"
         nopagenumber="$TitlePage"
-      >
-        ... Children here ...
-      </pagedef>
-    </loop>
-  </pdftemplate>
+    >
+
+      ... Children here ...
+
+    </pagedef>
+
+  </loop>
+
+</pdftemplate>
 
 =head1 AUTHOR
 
