@@ -14,11 +14,9 @@ sub enter_scope
     my $self = shift;
     my ($context) = @_;
 
-    $self->SUPER::enter_scope($context);
-
     $context->{X} = $context->get($self, 'LEFT_MARGIN');
 
-    return 1;
+    return $self->SUPER::enter_scope($context);
 }
 
 sub deltas
@@ -71,7 +69,7 @@ PDF::Template::Container
 =item * LEFT_MARGIN - If specifed, the row will start rendering here. Otherwise,
 it will default to the PAGEDEF's LEFT_MARGIN.
 
-=back
+=back 4
 
 =head1 CHILDREN
 
@@ -87,10 +85,13 @@ None
 
 =head1 USAGE
 
-  <row h="8">
-    <textbox w="50%" justify="right" text"Hello,"/>
-    <textbox w="50%" justify="left" text"World"/>
-  </row>
+<row h="8">
+
+  <textbox w="50%" justify="right" text"Hello,"/>
+
+  <textbox w="50%" justify="left" text"World"/>
+
+</row>
 
 =head1 AUTHOR
 
