@@ -15,7 +15,8 @@ BEGIN {
 # nor does it represent an XML object.    Rather, every container
 # will use this object to maintain the context for its children.
 
-sub new {
+sub new
+{
     my $class = shift;
     my $self = $class->SUPER::new(@_);
 
@@ -29,15 +30,16 @@ sub new {
     return $self;
 }
 
-sub param {
+sub param
+{
     my $self = shift;
     my ($param, $depth) = @_;
-    $param = uc $param;
     $depth ||= 0;
 
     my $val = undef;
     my $found = 0;
-    for my $map (reverse @{$self->{PARAM_MAP}}) {
+    for my $map (reverse @{$self->{PARAM_MAP}})
+    {
         next unless exists $map->{$param};
         $depth--, next if $depth;
 
@@ -64,7 +66,8 @@ my %isDimension = map { $_ => 1 } qw(
     SIZE WIDTH SCALE
 );
 
-sub resolve {
+sub resolve
+{
     my $self = shift;
     my ($obj, $key, $depth) = @_;
     $key = uc $key;
@@ -73,7 +76,8 @@ sub resolve {
     my $obj_val = $obj->{$key};
 
     my $is_param = 0;
-    if ($obj->{$key} =~ /^\$(\S+)$/o) {
+    if ($obj->{$key} =~ /^\$(\S+)$/o)
+    {
         $is_param = 1;
         $obj_val = $self->param($1)
     }
@@ -90,29 +94,35 @@ sub resolve {
     my ($op, $val, $unit) = $obj_val =~ m!^\s*([\+\*\/\-])?\s*([\d.]*\d)\s*([a-z%]+)?\s*$!oi;
     $op ||= '';
 
-    if ($unit) {
+    if ($unit)
+    {
         # Only the first character of the unit is useful, and it needs to be uppercase to key
         # into %PointsPer.
         my $uom = uc substr($unit, 0, 1);
 
-        if ($uom eq '%') {
+        if ($uom eq '%')
+        {
 #GGG Is this all that's needed?
-            if ($key eq 'W') {
+            if ($key eq 'W')
+            {
                 $val *= ($self->get($obj, 'PAGE_WIDTH') -
                             $self->get($obj, 'LEFT_MARGIN') -
                             $self->get($obj, 'RIGHT_MARGIN'));
             }
-            elsif ($key eq 'H') {
+            elsif ($key eq 'H')
+            {
                 $val *= ($self->get($obj, 'PAGE_HEIGHT') -
                             $self->get($obj, 'HEADER_HEIGHT') -
                             $self->get($obj, 'FOOTER_HEIGHT'));
             }
             $val /= 100;
         }
-        elsif (exists $PointsPer{$uom}) {
+        elsif (exists $PointsPer{$uom})
+        {
             $val *= $PointsPer{$uom};
         }
-        else {
+        else
+        {
             warn "'$unit' is not a recognized unit of measurement.", $/;
         }
 
@@ -134,7 +144,8 @@ sub resolve {
     return $val if $op eq '/' and $val == 0;
 
     my $new_val;
-    for ($op) {
+    for ($op)
+    {
         /^\+$/ && do { $new_val = ($prev_val + $val); last; };
         /^\-$/ && do { $new_val = ($prev_val - $val); last; };
         /^\*$/ && do { $new_val = ($prev_val * $val); last; };
@@ -147,13 +158,15 @@ sub resolve {
     return;
 }
 
-sub enter_scope {
+sub enter_scope
+{
     my $self = shift;
     my ($obj) = @_;
 
     push @{$self->{STACK}}, $obj;
 
-    for my $key (qw(X Y)) {
+    for my $key (qw(X Y))
+    {
         next unless exists $obj->{$key};
         $self->{$key} = $self->resolve($obj, $key);
     }
@@ -161,11 +174,13 @@ sub enter_scope {
     return 1;
 }
 
-sub exit_scope {
+sub exit_scope
+{
     my $self = shift;
     my ($obj, $no_delta) = @_;
 
-    unless ($no_delta) {
+    unless ($no_delta)
+    {
         my $deltas = $obj->deltas($self);
         $self->{$_} += $deltas->{$_} for keys %$deltas;
     }
@@ -175,7 +190,8 @@ sub exit_scope {
     return 1;
 }
 
-sub get {
+sub get
+{
     my $self = shift;
     my ($dummy, $key, $depth) = @_;
     $depth ||= 0;
@@ -184,7 +200,8 @@ sub get {
     return unless @{$self->{STACK}};
 
     my $obj = $self->{STACK}[-1];
-    if (exists $obj->{"TEMP_$key"}) {
+    if (exists $obj->{"TEMP_$key"})
+    {
         my $val = delete $obj->{"TEMP_$key"};
         return $val;
     }
@@ -193,7 +210,8 @@ sub get {
 
     my $val = undef;
     my $this_depth = $depth;
-    foreach my $e (reverse @{$self->{STACK}}) {
+    foreach my $e (reverse @{$self->{STACK}})
+    {
         next unless exists $e->{$key};
         next if $this_depth-- > 0;
 
@@ -209,7 +227,8 @@ sub get {
     return $val;
 }
 
-sub should_render {
+sub should_render
+{
     my $self = shift;
     my ($obj) = @_;
 
@@ -220,16 +239,15 @@ sub should_render {
     return $self->check_end_of_page($obj);
 }
 
-sub check_end_of_page {
+sub check_end_of_page
+{
     my $self = shift;
     my ($obj) = @_;
 
     my $deltas = $obj->deltas($self);
 
-    if (
-        ($self->get($obj, 'Y') || 0) + ($deltas->{Y} || 0)
-            < ($self->get($obj, 'END_Y') || 0)
-    ) {
+    if ($self->get($obj, 'Y') + $deltas->{Y} < $self->get($obj, 'END_Y'))
+    {
         $self->trip_pagebreak;
         return 0;
     }
@@ -237,14 +255,15 @@ sub check_end_of_page {
     return 1;
 }
 
-sub close_images {
+sub close_images
+{
     my $self = shift;
-    my $p = $self->{PDF};
 
-    $p->close_image($_) for values %{$self->{IMAGES}};
+    pdflib_pl::PDF_close_image($self->{PDF}, $_) for values %{$self->{IMAGES}};
 }
 
-sub new_page_def {
+sub new_page_def
+{
     my $self = shift;
 
     $self->{PARAM_MAP}[0]{__PAGEDEF__}++;
@@ -263,3 +282,31 @@ sub increment_pagenumber { $_[0]{PARAM_MAP}[0]{$_}++ for qw(__PAGE__ __PAGEDEF_P
 
 1;
 __END__
+
+=head1 NAME
+
+PDF::Template::Context
+
+=head1 PURPOSE
+
+=head1 NODE NAME
+
+=head1 INHERITANCE
+
+=head1 ATTRIBUTES
+
+=head1 CHILDREN
+
+=head1 AFFECTS
+
+=head1 DEPENDENCIES
+
+=head1 USAGE
+
+=head1 AUTHOR
+
+Rob Kinyon (rkinyon@columbus.rr.com)
+
+=head1 SEE ALSO
+
+=cut
