@@ -34,7 +34,7 @@ sub render
 
     my $p = $context->{PDF};
 
-    $p->save_state;
+    pdflib_pl::PDF_save($p);
 
     $self->set_color($context, 'COLOR', 'stroke');
 
@@ -42,20 +42,20 @@ sub render
     $self->set_color($context, 'FILLCOLOR', 'fill');
 
     my $width = $context->get($self, 'WIDTH') || 1;
-    $p->linewidth($width);
+    pdflib_pl::PDF_setlinewidth($p, $width);
 
-    $p->circle($x, $y, $r);
+    pdflib_pl::PDF_circle($p, $x, $y, $r);
 
     if (defined $fillcolor)
     {
-        $p->fill_stroke;
+        pdflib_pl::PDF_fill_stroke($p);
     }
     else
     {
-        $p->stroke;
+        pdflib_pl::PDF_stroke($p);
     }
 
-    $p->restore_state;
+    pdflib_pl::PDF_restore($p);
 
     return 1;
 }
@@ -84,53 +84,20 @@ PDF::Template::Element::Circle
 
 =head1 PURPOSE
 
-To draw a circle.
-
 =head1 NODE NAME
 
-CIRCLE
-
 =head1 INHERITANCE
 
-PDF::Template::Element
-
 =head1 ATTRIBUTES
 
-=over 4
-
-=item * R
-This is the radius of the circle to be drawn
-
-=item * COLOR
-This is the color the circle should be drawn in. Defaults to black.
-
-=item * FILLCOLOR
-This is the color the circle should be filled in with. Defaults to none.
-
-=item * WIDTH
-This is the width of the line used to draw the circle. Defaults to 1 pixel.
-
-=back
-
 =head1 CHILDREN
 
-None
-
 =head1 AFFECTS
 
-Nothing
-
 =head1 DEPENDENCIES
 
-None
-
 =head1 USAGE
 
-  <circle R="1i" color="255,0,0"/>
-
-This will cause a 1-inch radius circle to be drawn at the current position in
-red.
-
 =head1 AUTHOR
 
 Rob Kinyon (rkinyon@columbus.rr.com)
