@@ -19,7 +19,8 @@ sub render
     return 1 if $context->{CALC_LAST_PAGE};
 
     my $p = $context->{PDF};
-    $p->save_state;
+
+    pdflib_pl::PDF_save($p);
 
     $self->set_color($context, 'COLOR', 'both');
 
@@ -27,12 +28,12 @@ sub render
 
     my $width = $context->get($self, 'WIDTH') || 1;
 
-    $p->linewidth($width);
-    $p->move($vals->{X1}, $vals->{Y1});
-    $p->line($vals->{X2}, $vals->{Y2});
-    $p->stroke;
+    pdflib_pl::PDF_setlinewidth($p, $width);
+    pdflib_pl::PDF_moveto($p, $vals->{X1}, $vals->{Y1});
+    pdflib_pl::PDF_lineto($p, $vals->{X2}, $vals->{Y2});
+    pdflib_pl::PDF_stroke($p);
 
-    $p->restore_state;
+    pdflib_pl::PDF_restore($p);
 
     return 1;
 }
@@ -47,11 +48,8 @@ sub make_vals
     my %vals;
     unless (defined $x1 && defined $x2)
     {
-#GGG Is the use of W a potential bug here?
-        my ($pw, $left, $right, $w) = map {
-            $context->get($self, $_)
-        } qw( PAGE_WIDTH LEFT_MARGIN RIGHT_MARGIN W );
-
+#GGG Is the use of W a bug here?
+        my ($pw, $left, $right, $w) = map { $context->get($self, $_) } qw(PAGE_WIDTH LEFT_MARGIN RIGHT_MARGIN W);
         $w = $pw - $right - $left unless defined $w;
 
         if (defined $x1)
@@ -74,6 +72,7 @@ sub make_vals
 
     unless (defined $y1 && defined $y2)
     {
+        my $y = $context->get($self, 'Y');
         if (defined $y1)
         {
             $y2 = $y1;
@@ -84,7 +83,7 @@ sub make_vals
         }
         else
         {
-            $y1 = $y2 = $context->get($self, 'Y');
+            $y1 = $y2 = $y;
         }
     }
     @vals{qw(Y1 Y2)} = ($y1, $y2);
@@ -103,66 +102,24 @@ PDF::Template::Element::Line
 
 =head1 PURPOSE
 
-To draw lines
-
 =head1 NODE NAME
 
-LINE
-
 =head1 INHERITANCE
 
-PDF::Template::Element
-
 =head1 ATTRIBUTES
 
-=over 4
-
-=item * X1 / X2 / Y1 / Y2
-The line is drawn from (X1,Y1) to (X2,Y2).
-
-If neither X1 nor X2 are set, X1 is set to the lefthand margin and X2 is set
-to X1 + W. If only one is set, the other is set to the first +/- W.
-
-If either of the Y values is not set, it is set to the current Y value.
-
-=item * W
-This is the width of the line to be drawn. Used only in calculating X1/X2/Y1/Y2
-and only if needed. (q.v. above) Defaults to the distance between the left and
-right margins. (q.v. PAGEDEF for more information on these parameters.)
-
-=item * WIDTH
-This is the thickness of the line to be drawn. Defaults to 1 pixel.
-
-=item * COLOR
-This is the color to draw the line in. Defaults to black.
-
-=back
-
 =head1 CHILDREN
 
-PDF::Template::Element::HorizontalRule
-
 =head1 AFFECTS
 
-Nothing
-
 =head1 DEPENDENCIES
 
-None
-
 =head1 USAGE
 
-  <line X1="1i" Y1="1i" X2="3i" Y2="2i" WIDTH="3" COLOR="0,0,255"/>
-
-This will draw a blue line 3 pixels thick from the spot 1" in from the left and
-top to the spot 3" from the left and 2" from the top.
-
 =head1 AUTHOR
 
 Rob Kinyon (rkinyon@columbus.rr.com)
 
 =head1 SEE ALSO
 
-PAGEDEF, HR
-
 =cut
