@@ -22,15 +22,16 @@ sub render
 
     unless (defined $url)
     {
-        warn "Weblink: no URL defined!", $/;
+        warn "Weblink: no text defined!", $/;
         return 1;
     }
 
-    my @dimensions = map {
-        $context->get($self, $_) || 0
-    } qw( X1 Y1 X2 Y2 );
-
-    $context->{PDF}->add_weblink( @dimensions, $url );
+    pdflib_pl::PDF_add_weblink(
+        $context->{PDF},
+        $self->{X1}, $self->{Y1},
+        $self->{X2}, $self->{Y2},
+        $url,
+    );
 
     return 1;
 }
@@ -44,48 +45,20 @@ PDF::Template::Element::WebLink
 
 =head1 PURPOSE
 
-To provide a clickable web-link
-
 =head1 NODE NAME
 
-WEBLINK
-
 =head1 INHERITANCE
 
-PDF::Template::Element
-
 =head1 ATTRIBUTES
 
-=over 4
-
-=item * URL
-The URL to go to, when clicked
-
-=item * X1 / X2 / Y1 / Y2
-
-The dimensions of the clickable area
-
-=back
-
 =head1 CHILDREN
 
-None
-
 =head1 AFFECTS
 
-Nothing
-
 =head1 DEPENDENCIES
 
-None
-
 =head1 USAGE
 
-This node is currently under review as to whether it should be removed and a
-URL attribute should be added to various nodes, such as IMAGE, TEXTBOX, and ROW.
-
-=head2 USE AT YOUR OWN RISK
-
 =head1 AUTHOR
 
 Rob Kinyon (rkinyon@columbus.rr.com)
