@@ -53,11 +53,6 @@ sub new
         return $self;
     }
 
-    unless (@{$self->{DATA}})
-    {
-        $self->{NO_PARAMS} = 1;
-    }
-
     $self->{MAX_INDEX} = $#{$self->{DATA}};
 
     return $self;
@@ -69,10 +64,6 @@ sub enter_scope
 
     return 0 if $self->{NO_PARAMS};
 
-    for my $x ($self->{DATA}[$self->{INDEX}])
-    {
-        $x->{uc $_} = delete $x->{$_} for keys %$x;
-    }
     push @{$self->{CONTEXT}{PARAM_MAP}}, $self->{DATA}[$self->{INDEX}];
 
     return 1;
@@ -214,3 +205,31 @@ sub reset
 
 1;
 __END__
+
+=head1 NAME
+
+PDF::Template::Iterator
+
+=head1 PURPOSE
+
+=head1 NODE NAME
+
+=head1 INHERITANCE
+
+=head1 ATTRIBUTES
+
+=head1 CHILDREN
+
+=head1 AFFECTS
+
+=head1 DEPENDENCIES
+
+=head1 USAGE
+
+=head1 AUTHOR
+
+Rob Kinyon (rkinyon@columbus.rr.com)
+
+=head1 SEE ALSO
+
+=cut
