@@ -8,7 +8,7 @@ BEGIN {
 
     use PDF::Template::Base;
 
-    use Encode;
+UNI_YES    use Unicode::String;
 }
 
 # This is a helper object. It is not instantiated by the user,
@@ -31,7 +31,8 @@ sub resolve
     my $self = shift;
     my ($context) = @_;
 
-    my $t = '';
+UNI_YES    my $t = Unicode::String::utf8('');
+UNI_NO     my $t = '';
 
     for my $tok (@{$self->{STACK}})
     {
@@ -39,14 +40,8 @@ sub resolve
         $val = $val->resolve($context)
             if PDF::Template::Factory::isa($val, 'VAR');
 
-        my $encoding = $context->get($self, 'PDF_ENCODING');
-        if ($encoding) {
-            if (Encode::is_utf8($val)) {
-                $val = Encode::encode($encoding,$val);
-            }
-        }
-
-        $t .= $val;
+UNI_YES        $t .= Unicode::String::utf8("$val");
+UNI_NO         $t .= $val;
     }
 
     return $t;
@@ -54,3 +49,31 @@ sub resolve
 
 1;
 __END__
+
+=head1 NAME
+
+PDF::Template::TextObject
+
+=head1 PURPOSE
+
+=head1 NODE NAME
+
+=head1 INHERITANCE
+
+=head1 ATTRIBUTES
+
+=head1 CHILDREN
+
+=head1 AFFECTS
+
+=head1 DEPENDENCIES
+
+=head1 USAGE
+
+=head1 AUTHOR
+
+Rob Kinyon (rkinyon@columbus.rr.com)
+
+=head1 SEE ALSO
+
+=cut
